<?php

namespace Litecms\FundTransferSetting\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\FundTransferSetting\Models\FtSetting;

class FtSettingPolicy
{

    /**
     * Determine if the given user can view the ft_setting.
     *
     * @param UserPolicy $user
     * @param FtSetting $ft_setting
     *
     * @return bool
     */
    public function view(UserPolicy $user, FtSetting $ft_setting)
    {
        if ($user->canDo('fund_transfer_setting.ft_setting.view') && $user->isAdmin()) {
            return true;
        }

        return $ft_setting->user_id == user_id() && $ft_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can create a ft_setting.
     *
     * @param UserPolicy $user
     * @param FtSetting $ft_setting
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('fund_transfer_setting.ft_setting.create');
    }

    /**
     * Determine if the given user can update the given ft_setting.
     *
     * @param UserPolicy $user
     * @param FtSetting $ft_setting
     *
     * @return bool
     */
    public function update(UserPolicy $user, FtSetting $ft_setting)
    {
        if ($user->canDo('fund_transfer_setting.ft_setting.edit') && $user->isAdmin()) {
            return true;
        }

        return $ft_setting->user_id == user_id() && $ft_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given ft_setting.
     *
     * @param UserPolicy $user
     * @param FtSetting $ft_setting
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, FtSetting $ft_setting)
    {
        return $ft_setting->user_id == user_id() && $ft_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given ft_setting.
     *
     * @param UserPolicy $user
     * @param FtSetting $ft_setting
     *
     * @return bool
     */
    public function verify(UserPolicy $user, FtSetting $ft_setting)
    {
        if ($user->canDo('fund_transfer_setting.ft_setting.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given ft_setting.
     *
     * @param UserPolicy $user
     * @param FtSetting $ft_setting
     *
     * @return bool
     */
    public function approve(UserPolicy $user, FtSetting $ft_setting)
    {
        if ($user->canDo('fund_transfer_setting.ft_setting.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
