<?php

namespace Litecms\FundTransferSetting\Providers;

use Illuminate\Support\ServiceProvider;

class FundTransferSettingServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'fund_transfer_setting');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'fund_transfer_setting');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFundTransferSetting();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerFundTransferSetting()
    {
        $this->app->bind('fund_transfer_setting', function($app) {
            return new FundTransferSetting($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('FundTransferSetting', 'Lavalite\FundTransferSetting\Facades\FundTransferSetting');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('litecms.fund_transfer_setting', function ($app) {
            return $this->app->make('Litecms\FundTransferSetting\FundTransferSetting');
        });

                // Bind FtSetting to repository
        $this->app->bind(
            'Litecms\FundTransferSetting\Interfaces\FtSettingRepositoryInterface',
            \Litecms\FundTransferSetting\Repositories\Eloquent\FtSettingRepository::class
        );

        $this->app->register(\Litecms\FundTransferSetting\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\FundTransferSetting\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and fund_transfer_setting's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/fund_transfer_setting.php', 'fund_transfer_setting'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeFundTransferSetting::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.fund_transfer_setting'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/fund_transfer_setting.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/fund_transfer_setting')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/fund_transfer_setting')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
